#include <cstdio>
#include <tr1/unordered_map>
#include <tr1/unordered_set>
#include <queue>
#include <vector>
#include <cassert>
#include <algorithm>
#include <fstream>
#include <string>

namespace std {
  namespace tr1 {

    template<typename a, typename b>
      struct hash< std::pair<a, b> > {
        private:
          const hash<a> ah;
          const hash<b> bh;
        public:
          hash() : ah(), bh() {}
          size_t operator()(const std::pair<a, b> &p) const {
            size_t bb = bh(p.second);
            return ah(p.first) ^ (bb << 3) ^ bb;
          }
      };

    template<typename a>
      struct hash< std::vector<a> > {
        private:
          const hash<a> ah;
        public:
          hash() : ah() {}
          size_t operator()(const std::vector<a> &p) const {
            size_t ret = 0;
            for (auto it = p.begin(); it != p.end(); ++it) {
              ret = (ret << 3) ^ ret;
              ret ^= ah(*it);
            }
            return ret;
          }
      };

  }}

using namespace std;
using namespace std::tr1;

bool Check3A(int r, int c, int x1, int y1, int x2, int y2) {
  int c1 = (x1 + y1) % 2;
  int c2 = (x2 + y2) % 2;
  if (c1 == 1 && c2 == 0) {
    if (y1 == 2 && x1 < x2) return true;
    if (y1 != 2 && x1 < x2 - 1) return true;
  }
  return false;
}

bool Check3(int r, int c, int x1, int y1, int x2, int y2) {
  if (r != 3) return false;
  if (c % 2 != 0) return false;
  return Check3A(r, c, x1, y1, x2, y2) ||
         Check3A(r, c, x2, y2, x1, y1) ||
         Check3A(r, c, c - x1 + 1, y1, c - x2 + 1, y2) ||
         Check3A(r, c, c - x2 + 1, y2, c - x1 + 1, y1);
}

int upper(int r, int c, int x1, int y1, int x2, int y2) {
  if (r > c) {
    return upper(c, r, y1, x1, y2, x2);
  }
  if (r == 1) return abs(x1 - x2) + 1;
  if (r == 2 && (abs(x1 - x2) <= 1) && y1 != y2) {
    return max(x1+x2, 2*c - x1 - x2 + 2); 
  }
  int c1 = (x1 + y1) % 2;
  int c2 = (x2 + y2) % 2;
  bool con3 = Check3(r, c, x1, y1, x2, y2);

  if (r*c % 2 == 0 && c1 != c2 && con3 == false) {
    return r*c;
  }
  if (r*c % 2 == 1 && c1 == 0 && c2 == 0 && con3 == false) {
    return r*c;
  }
  if (r*c % 2 == 0 && c1 == c2) {
    return r*c - 1;
  }
  if (r*c % 2 == 1 && c1 != c2) {
    return r*c - 1;
  }
  if (r*c % 2 == 1 && c1 == 1 && c2 == 1) {
    return r*c - 2;
  }
  if (r*c % 2 == 0 && c1 != c2 && con3 == true) {
    return r*c - 2;
  }
  if (r*c % 2 == 1 && c1 == 0 && c2 == 0 && con3 == true) {
    return r*c - 2;
  }
  assert(false);
}

int main(int argc, char** argv) {
  if (argc != 3) {
    printf("Usage: ./checker <input> <output>\n");
    return 1;
  }
  FILE *input = fopen(argv[1], "r");
  ifstream output(argv[2]);

  int t; fscanf(input, "%d", &t);
  for (int i = 0; i < t; i++) {
    int r, c, x1, x2, y1, y2;
    fscanf(input, "%d %d %d %d %d %d", &r, &c, &x1, &y1, &x2, &y2);
    int expectl = upper(r, c, x1, y1, x2, y2);
    unordered_set<pair<int, int> > visited;
    string solution;
    if (!(output >> solution)) {
      printf("Missing data in solution\n");
      return 1;
    }
    pair<int, int> current(x1, y1);
    visited.insert(current);
    int theirl = solution.length() + 1;
    for (int j = 0; j < solution.length(); j++) {
      if (solution[j] == 'U') current.second++;
      else if (solution[j] == 'D') current.second--;
      else if (solution[j] == 'L') current.first--;
      else if (solution[j] == 'R') current.first++;
      else {
        printf("Invalid path\n");
        return 1;
      }
      if (current.first <= 0 || current.second <= 0 ||
          current.first > c || current.second > r) {
        printf("Invalid path\n");
        return 1;
      }
      if (visited.count(current)) {
        printf("Invalid path\n");
        return 1;
      }
      visited.insert(current);
    }
    if (current != make_pair(x2, y2)) {
      printf("Invalid path\n");
      return 1;
    }
    if (theirl < expectl) {
      printf("Path too short\n");
      return 1;
    }
  }
  return 0;
}
